@@ -451,7 +451,7 @@ class Base(Controller):
         primary_key = self.app.pargs.__dict__.get('pk') or self.app.pargs.__dict__.get('primary_key')
         delimiter = self.app.pargs.__dict__.get('d') or ','
         
-        generate_fake_data(n_lines, template, delimiter, columns, csv, primary_key)
+        generate_fake_data(n_lines, template, columns, csv, primary_key, delimiter)
         
 
     @ex(
@@ -895,10 +895,15 @@ class Base(Controller):
             })
         ]
     )
-    def ms_outlook(self):
-        from ..ext.ms_outlook import add_event, list_events, delete_event
+    def ms(self):
+        # extract arguments and pass to the appropriate function
+        invitees = self.app.pargs.__dict__.get('invite', None) or self.app.pargs.__dict__.get('i', None)
+        start = self.app.pargs.__dict__.get('start', None) or self.app.pargs.__dict__.get('s', None)
+        duration = self.app.pargs.__dict__.get('duration', None) or self.app.pargs.__dict__.get('d', None)
+        
+        from ..ext.ms_outlook import create_meeting, list_events, delete_event
         if self.app.pargs.action=='add':
-            add_event(self.app.pargs.t, self.app.pargs.i, self.app.pargs.s, self.app.pargs.d)
+            create_meeting(self.app.pargs.t, invitees, start, duration)
         elif self.app.pargs.action=='ls':
             list_events()
         elif self.app.pargs.action=='del':
