@@ -80,7 +80,13 @@ def get_client(oauth=False):
         with open(os.path.expanduser('~/.dt_config.json')) as f:
             config = json.load(f)
         
-        client = asana.Client.access_token(config['asana_token']['access_token'])
+        try:
+            client = asana.Client.access_token(config['asana_token']['access_token'])
+        except KeyError:
+            print("Insufficient token found. Getting new token...")
+            token, client = get_oauth_token(config)
+            
+        
         if client.session.authorized == False:
             print("Insufficient token found. Getting new token")
             token, client = get_oauth_token(config)
